AddressModel class
Dirección física del usuario. Incluye coordenadas para potencial uso en mapas o filtros.
Constructors
- AddressModel({required String city, required String street, required int number, required String zipCode, required GeolocationModel geolocation})
-
const
Properties
- city → String
-
final
- geolocation → GeolocationModel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- street → String
-
final
- zipCode → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited