UserModel class

Representa un usuario registrado en la Fake Store API.

Combina datos básicos de autenticación ligera (username/email) con información de perfil y dirección. Se mantiene deliberadamente simple. No expone password por seguridad (la API original regresa un campo, pero evitamos propagarlo a la capa de dominio de ejemplo).

Constructors

UserModel({required int id, required String email, required String username, required NameModel name, required AddressModel address, required String phone})
const

Properties

address AddressModel
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
name NameModel
final
phone String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited