CreateUserInput class
Datos necesarios para crear un nuevo usuario en FakeStore API.
Contiene también el password (no se expone en UserModel).
Constructors
- CreateUserInput({required String email, required String username, required String password, required String firstName, required String lastName, required String city, required String street, required int number, required String zipCode, required String geoLat, required String geoLong, required String phone})
-
const
- CreateUserInput.minimal({required String email, required String username, required String password})
-
Fábrica conveniente para creación mínima (solo credenciales básicas).
Los demás campos se rellenan con valores por defecto.
factory
Properties
- city → String
-
final
- email → String
-
final
- firstName → String
-
final
- geoLat → String
-
final
- geoLong → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastName → String
-
final
- number → int
-
final
- password → String
-
final
- phone → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- street → String
-
final
- username → String
-
final
- zipCode → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited