UserModel class
Representa un usuario registrado en la Fake Store API.
Combina datos básicos de autenticación ligera (username/email) con información de perfil y dirección. Se mantiene deliberadamente simple. No expone password por seguridad (la API original regresa un campo, pero evitamos propagarlo a la capa de dominio de ejemplo).
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited